==> aspectj_1.5.4.orig.tar.gz: aspectj_1.5.4.orig/org.aspectj/modules/ajde/src/org/aspectj/ajde/internal/LstBuildConfigFileParser.java <==
/* *******************************************************************
 * Copyright (c) 1999-2001 Xerox Corporation, 
 *               2002 Palo Alto Research Center, Incorporated (PARC).
 * All rights reserved. 
 * This program and the accompanying materials are made available 
 * under the terms of the Eclipse Public License v1.0 
 * which accompanies this distribution and is available at 
 * http://www.eclipse.org/legal/epl-v10.html 
 *  
 * Contributors: 
 *     Xerox/PARC     initial implementation 
 * ******************************************************************/


package org.aspectj.ajde.internal;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.aspectj.util.ConfigParser;

/**
 * @author Mik Kersten
 */
public class LstBuildConfigFileParser extends ConfigParser {

	private List importedFiles = new ArrayList();
	private List problemEntries = new ArrayList();

//	private String currFilePath;

	public LstBuildConfigFileParser(String currFilePath) {
//		this.currFilePath = currFilePath;		
	}  

    protected void showWarning(String message) {
    	problemEntries.add(message);
    }
    
	protected void parseImportedConfigFile(String relativeFilePath) {
		importedFiles.add(makeFile(relativeFilePath));
		super.files.add(new File(relativeFilePath));
		super.parseImportedConfigFile(relativeFilePath);	
	} 
	
    protected void showError(String message) {
        problemEntries.add(message);
    }
	
	public List getImportedFiles() {
		return importedFiles;
	}
	
	public List getProblemEntries() {
		return problemEntries;	
	}
}

==> aspectj_1.6.9+dfsg.orig.tar.gz: aspectj-1.6.9+dfsg/org.aspectj/modules/ajde/src/org/aspectj/ajde/internal/LstBuildConfigFileParser.java <==
/* *******************************************************************
 * Copyright (c) 1999-2001 Xerox Corporation, 
 *               2002 Palo Alto Research Center, Incorporated (PARC).
 * All rights reserved. 
 * This program and the accompanying materials are made available 
 * under the terms of the Eclipse Public License v1.0 
 * which accompanies this distribution and is available at 
 * http://www.eclipse.org/legal/epl-v10.html 
 *  
 * Contributors: 
 *     Xerox/PARC     initial implementation 
 * ******************************************************************/


package org.aspectj.ajde.internal;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.aspectj.ajdt.ajc.ConfigParser;

/**
 * @author Mik Kersten
 */
public class LstBuildConfigFileParser extends ConfigParser {

	private List importedFiles = new ArrayList();
	private List problemEntries = new ArrayList();

//	private String currFilePath;

	public LstBuildConfigFileParser(String currFilePath) {
//		this.currFilePath = currFilePath;		
	}  

    protected void showWarning(String message) {
    	problemEntries.add(message);
    }
    
	protected void parseImportedConfigFile(String relativeFilePath) {
		importedFiles.add(makeFile(relativeFilePath));
		super.files.add(new File(relativeFilePath));
		super.parseImportedConfigFile(relativeFilePath);	
	} 
	
    protected void showError(String message) {
        problemEntries.add(message);
    }
	
	public List getImportedFiles() {
		return importedFiles;
	}
	
	public List getProblemEntries() {
		return problemEntries;	
	}
}
